@@ -40,13 +40,18 @@ function(my.string, use.letters=TRUE,
         }
     
      # create a matrix with all combinations of prime implicants to be compared for similar literals
-    all.combs <- as.matrix(combn(length(list.my.string), 2))
+    # all.combs <- as.matrix(combn(length(list.my.string), 2))
+    all.combs <- createMatrix(rep(2, length(list.my.string)))
+    all.combs <- all.combs[rowSums(all.combs) > 1, ]
+    all.combs <- col(all.combs) * as.vector(all.combs)
     
      # create a list with matched literals between prime implicants
-    match.list <- as.list(apply(all.combs, 2, function(x) {
-        matches <- match(list.my.string[[x[1]]], list.my.string[[x[2]]])
-        if (!all(is.na(matches))) list.my.string[[x[1]]][which(matches > 0)] else NA
+    match.list <- as.list(apply(all.combs, 1, function(x) {
+        x <- list.my.string[x[x > 0]]
+        y <- table(unlist(x))
+        return(names(y)[y == length(x)])
         }))
+    
     names(match.list) <- lapply(match.list, paste, collapse=collapsemethod)
     
      # see wich comparisons didn't yield similar literals
@@ -54,19 +59,19 @@ function(my.string, use.letters=TRUE,
      # erase those branches from the list
     match.list <- match.list[!null.branches]
      # and from all combinations
-    all.combs <- all.combs[, !null.branches, drop=FALSE]
+    all.combs <- all.combs[!null.branches, , drop=FALSE]
     
     if (sort.by.literals) {
         sort.by.number <- FALSE
         lengths.vector <- as.numeric(unlist(lapply(match.list, length)))
         match.list <- match.list[rev(order(lengths.vector))]
-        all.combs <- all.combs[, rev(order(lengths.vector))]
+        all.combs <- all.combs[rev(order(lengths.vector)), ]
         }
     
      # prepare a vector showing which columns from all.combs have been used
      # to extract common.factor factors
-    selected.cols <- rep(FALSE, ncol(all.combs))
-    complex.list <- vector("list", length(selected.cols))
+    selected.rows <- rep(FALSE, nrow(all.combs))
+    complex.list <- vector("list", length(selected.rows))
     
     
     extract <- function(match.list, all.combs, complex.list, my.string.index) {
@@ -78,29 +83,31 @@ function(my.string, use.letters=TRUE,
             
             if (any(similar.branches)) {
                  # see which are the other similar branches
-                similar.index <- (1:length(match.list))[-i][similar.branches]
+                similar.index <- seq(length(match.list))[-i][similar.branches]
                  # see which are the prime implicants with similar common.factor factors
-                my.string.index <- sort(unique(c(all.combs[, c(i, similar.index)])))
+                my.string.index <- sort(unique(c(all.combs[c(i, similar.index), ])))
+                my.string.index <- my.string.index[my.string.index > 0]
                 }
             else {
-                 # see which are the prime implicants with similar common.factor factors
-                my.string.index <- c(all.combs[, i])
+                 # see which are the prime implicants with similar common factors
+                my.string.index <- all.combs[i, ]
+                my.string.index <- my.string.index[my.string.index > 0]
                 }
                 
              # paste the other literals from each index, separated by " + "
             sol <- paste(sapply(my.string.index, function(x) {
-                    paste(list.my.string[[x]][!(list.my.string[[x]] %in% common.factor)], collapse=collapsemethod)
+                    paste(list.my.string[[x]][!list.my.string[[x]] %in% common.factor], collapse=collapsemethod)
                     }), collapse=" + ")
             
             common.factor <- paste(match.list[[i]], collapse=collapsemethod)
             
              # then combine everything having the common.factor in front of the paranthesys
             factor.sol <- paste(common.factor, collapsemethod, "(", sol, ")", sep="")
-            selected.cols <- apply(all.combs, 2, function(x) any(x %in% my.string.index))
+            selected.rows <- apply(all.combs, 1, function(x) any(x %in% my.string.index))
             
             if (!is.null(initial.index)) my.string.index <- sort(unique(c(initial.index, my.string.index)))
             
-            if (sum(!selected.cols) == 0) {
+            if (sum(!selected.rows) == 0) {
                  # no other comparison can be made; add all other prime implicants that have not been used
                 if (length(my.string[-my.string.index]) > 0) {
                         factor.sol <- paste(factor.sol, paste(my.string[-my.string.index], collapse=" + "), sep=" + ")
@@ -112,17 +119,17 @@ function(my.string, use.letters=TRUE,
                 sift <- function(x, y, z) {
                     sift.list <- list(match.list=NULL, all.combs=NULL)
                     sift.list[[1]] <- x[!z]
-                    sift.list[[2]] <- y[, which(!z), drop=FALSE]
+                    sift.list[[2]] <- y[which(!z), , drop=FALSE]
                     sift.list
                     }
-                sift.list <- sift(match.list, all.combs, selected.cols)
+                sift.list <- sift(match.list, all.combs, selected.rows)
                 
                 names(complex.list)[i] <- factor.sol
                 complex.list[[i]] <- vector("list", length(sift.list$match.list))
                 complex.list[[i]] <- Recall(sift.list$match.list, sift.list$all.combs, complex.list[[i]], my.string.index)
                 }
             }
-        complex.list
+        return(complex.list)
         }
     
     
@@ -174,3 +181,4 @@ function(my.string, use.letters=TRUE,
         cat("\nSolution:", final.solution, "\n\n")
         }
     }
+
